<?php

// Abort by direct access
if (!defined('ABSPATH')) {
    die;
}

/**
 * ZDM core main class
 */
class ZDMCore {

    protected $plugin_basename;

    /**
     * Constructor
     */
    function __construct() {
        $this->plugin_basename = plugin_basename(ZDM__PATH . ZDM__SLUG . '.php');
    }

    /**
     * Creates an entry in the backend with several pages in the menu
     *
     * @return void
     */
    public function admin_menu() {
        add_menu_page(
            ZDM__TITLE,                             // Page title
            ZDM__TITLE,                             // Menu text
            ZDM__STANDARD_USER_ROLE,                // Access level
            ZDM__SLUG,                              // Path of the function, __FILE__ means the function is in this file
            array($this, 'admin_menu_dashboard'),   // Name of the function that is being executed
            'dashicons-download');                  // Dashicon in the admin menu
        add_submenu_page(
            ZDM__SLUG,                              // top-level menu
            esc_html__('Files', 'zdm'),             // Page title
            esc_html__('Files', 'zdm'),             // Menu text
            ZDM__STANDARD_USER_ROLE,                // Access level
            ZDM__SLUG . '-files',                   // URL of submenue
            array($this, 'admin_menu_files'));      // Name of the function that is being executed
        add_submenu_page(
            ZDM__SLUG,
            esc_html__('Add file', 'zdm'),
            esc_html__('Add file', 'zdm'),
            ZDM__STANDARD_USER_ROLE,
            ZDM__SLUG . '-add-file',
            array($this, 'admin_menu_add_file'));
        add_submenu_page(
            ZDM__SLUG,
            esc_html__('Archives', 'zdm'),
            esc_html__('Archives', 'zdm'),
            ZDM__STANDARD_USER_ROLE,
            ZDM__SLUG . '-ziparchive',
            array($this, 'admin_menu_ziparchive'));
        add_submenu_page(
            ZDM__SLUG,
            esc_html__('Create archive', 'zdm'),
            esc_html__('Create archive', 'zdm'),
            ZDM__STANDARD_USER_ROLE,
            ZDM__SLUG . '-add-archive',
            array($this, 'admin_menu_add_archive'));
        add_submenu_page(
            ZDM__SLUG,
            esc_html__('Settings', 'zdm'),
            esc_html__('Settings', 'zdm'),
            ZDM__STANDARD_USER_ROLE,
            ZDM__SLUG . '-settings',
            array($this, 'admin_menu_settings'));
        add_submenu_page(
            ZDM__SLUG,
            esc_html__('Help', 'zdm'),
            esc_html__('Help', 'zdm'),
            ZDM__STANDARD_USER_ROLE,
            ZDM__SLUG . '-help',
            array($this, 'admin_menu_help'));
        if ($this->licence() != true) {
            add_submenu_page(
                ZDM__SLUG,
                esc_html__('Upgrade', 'zdm'),
                esc_html__('Upgrade', 'zdm'),
                ZDM__STANDARD_USER_ROLE,
                ZDM__PRO_URL);
        }
        add_submenu_page(
            null,
            esc_html__('Help', 'zdm'),
            esc_html__('Help', 'zdm'),
            ZDM__STANDARD_USER_ROLE,
            ZDM__SLUG . '-log',
            array($this, 'admin_hidden_log'));
    }

    /**
     * Admin menu new archive
     *
     * @return void
     */
    public function admin_menu_add_archive() {
        require_once (plugin_dir_path(__FILE__) . '../templates/admin_menu_add_archive.php');
    }

    /**
     * Admin menu add file
     *
     * @return void
     */
    public function admin_menu_add_file() {
        require_once (plugin_dir_path(__FILE__) . '../templates/admin_menu_add_file.php');
    }

    /**
     * Admin menu dashboard
     *
     * @return void
     */
    public function admin_menu_dashboard() {
        require_once (plugin_dir_path(__FILE__) . '../templates/admin_menu_dashboard.php');
    }

    /**
     * Admin menu files
     *
     * @return void
     */
    public function admin_menu_files() {
        require_once (plugin_dir_path(__FILE__) . '../templates/admin_menu_files.php');
    }

    /**
     * Admin menu settings
     *
     * @return void
     */
    public function admin_menu_settings() {
        require_once (plugin_dir_path(__FILE__) . '../templates/admin_menu_settings.php');
    }

    /**
     * Admin menu archives
     *
     * @return void
     */
    public function admin_menu_ziparchive() {
        require_once (plugin_dir_path(__FILE__) . '../templates/admin_menu_ziparchive.php');
    }

    /**
     * Hides admin help
     *
     * @return void
     */
    public function admin_menu_help() {
        require_once (plugin_dir_path(__FILE__) . '../templates/admin_menu_help.php');
    }

    /**
     * Admin log (hidden)
     *
     * @return void
     */
    public function admin_hidden_log() {
        require_once (plugin_dir_path(__FILE__) . '../templates/admin_hidden_log.php');
    }

    /**
     * Checks whether a special file is linked to an archive
     * 
     * @param int $file_id
     * @param int $archive_id
     * @return bool
     */
    public function check_file_rel_to_archive($files_id, $archive_id) {
        global $wpdb;

        $tablename_files_rel = $wpdb->prefix . "zdm_files_rel";

        // Get data from the database (files_rel)
        $db_file_rel = $wpdb->get_results(
            "
            SELECT id 
            FROM $tablename_files_rel 
            WHERE id_file = '$files_id' 
            AND id_archive = '$archive_id'
            "
            );

        if ($db_file_rel[0] === NULL) {
            return false;
        } else {
            return true;
        }
    }

    /**
     * Checks file associations and updates the cache
     *
     * @param int $archive_id
     * @return void
     */
    public function check_files_from_archive($archive_id) {

        global $wpdb;
        
        $tablename_files_rel = $wpdb->prefix . "zdm_files_rel";

        // Get data from the database (files_rel)
        $db_files_rel = $wpdb->get_results(
            "
            SELECT id 
            FROM $tablename_files_rel 
            WHERE file_updated = '1' 
            AND id_archive = '$archive_id'
            "
            );

        if (count($db_files_rel) > 0) {
            $this->create_archive_cache($archive_id);
        }
    }

    /**
     * Checks whether a file is linked to an archive
     * 
     * @param int $archive_id
     * @return bool
     */
    public function check_if_any_file_rel_to_archive($archive_id) {
        global $wpdb;
        
        $tablename_files_rel = $wpdb->prefix . "zdm_files_rel";

        // Get data from the database (files_rel)
        $db_files_rel = $wpdb->get_results(
            "
            SELECT id 
            FROM $tablename_files_rel 
            WHERE id_archive = '$archive_id'
            "
            );

        if (count($db_files_rel) > 0) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * Prüft ob die Datei in einem Archiv verknüpft ist
     *
     * @param int $files_id
     * @return mixed
     */
    public function check_if_file_is_in_archive($files_id) {
        global $wpdb;

        $tablename_files_rel = $wpdb->prefix . "zdm_files_rel";

        // Get data from the database (files_rel)
        $db_file_rel = $wpdb->get_results(
            "
            SELECT id 
            FROM $tablename_files_rel 
            WHERE id_file = '$files_id'
            "
            );

        $db_count = count($db_file_rel);

        if ($db_count > 0) {
            return $db_count;
        } else {
            return false;
        }
    }

    /**
     * Checks whether all files in an archive are up to date
     *
     * @param int $archive_id
     * @return bool
     */
    public function check_if_archive_cache_ok($archive_id) {

        global $wpdb;
        
        $tablename_files_rel = $wpdb->prefix . "zdm_files_rel";

        // Get data from the database (files_rel)
        $db_files_rel = $wpdb->get_results(
            "
            SELECT id 
            FROM $tablename_files_rel 
            WHERE file_updated = '1' 
            AND id_archive = '$archive_id'
            "
            );

        // Get data from the database (files_rel)
        $db_files_rel_check_archive = $wpdb->get_results(
            "
            SELECT id 
            FROM $tablename_files_rel 
            WHERE id_archive = '$archive_id'
            "
            );
        
        // Check whether the archive contains a file
        if (count($db_files_rel_check_archive) < 1) {
            return false;
        } else {

            // Check whether a file has been changed
            if (count($db_files_rel) > 0) {
                return false;
            } else {
                return true;
            }
        }
    }

    /**
     * Checks whether an archive exists
     *
     * @param int $archive_id
     * @return bool
     */
    public function check_if_archive_exists($archive_id) {

        if (is_numeric($archive_id)) {
            global $wpdb;
            
            $tablename_archives = $wpdb->prefix . "zdm_archives";
    
            // Get data from the database (archives)
            $db_archives = $wpdb->get_results(
                "
                SELECT id 
                FROM $tablename_archives 
                WHERE id = '$archive_id'
                "
                );
    
            if (count($db_archives) > 0) {
                return true;
            } else {
                return false;
            }
        } else {
            return false;
        }
    }

    /**
     * Checks whether a file exists
     *
     * @param int $file_id
     * @return bool
     */
    public function check_if_file_exists($file_id) {

        if (is_numeric($file_id)) {
            global $wpdb;
            
            $tablename_files = $wpdb->prefix . "zdm_files";
    
            // Get data from the database (files)
            $db_files = $wpdb->get_results(
                "
                SELECT id 
                FROM $tablename_files 
                WHERE id = '$file_id'
                "
                );
    
            if (count($db_files) >= 1) {
                return true;
            } else {
                return false;
            }
        } else {
            return false;
        }
    }

    /**
     * Creates cache file from archive
     *
     * @param int $archive_id
     * @return void
     */
    public function create_archive_cache($archive_id) {

        $time = time();

        global $wpdb;

        $tablename_archives = $wpdb->prefix . "zdm_archives";
        $tablename_files_rel = $wpdb->prefix . "zdm_files_rel";

        // Get data from the database (archives)
        $db_archive = $wpdb->get_results(
            "
            SELECT * 
            FROM $tablename_archives 
            WHERE id = '$archive_id'
            "
            );

        // Get data from the database (files_rel)
        $db_files_rel = $wpdb->get_results(
            "
            SELECT * 
            FROM $tablename_files_rel 
            WHERE id_archive = '$archive_id' 
            AND file_deleted = '0'
            "
            );
        
        $db_files_rel_count = count($db_files_rel);

        // Delete old file and folder
        $old_cache_folder = ZDM__DOWNLOADS_CACHE_PATH . '/' . $db_archive[0]->archive_cache_path;
        $old_cache_file = $old_cache_folder . '/' . $db_archive[0]->zip_name . '.zip';
        $old_cache_index = $old_cache_folder . '/' . 'index.php';
        if (file_exists($old_cache_file)) {
            unlink($old_cache_file);
        }
        if (file_exists($old_cache_index)) {
            unlink($old_cache_index);
        }
        if ($db_archive[0]->archive_cache_path != '') {
            if (is_dir($old_cache_folder)) {
                rmdir($old_cache_folder);
            }
        }
        
        // Archive cache path
        // Create folder name
        $archive_cache_path = md5(time() . $archive_id);

        // Create folder
        if (!is_dir(ZDM__DOWNLOADS_CACHE_PATH . '/' . $archive_cache_path)) {
            wp_mkdir_p(ZDM__DOWNLOADS_CACHE_PATH . '/' . $archive_cache_path);
        }

        // Cache file path
        $file_path = ZDM__DOWNLOADS_CACHE_PATH . '/' . $archive_cache_path . '/' . $db_archive[0]->zip_name . '.zip';

        // Create index.php
        $index_file_handle = fopen(ZDM__DOWNLOADS_CACHE_PATH . '/' . $archive_cache_path . '/' . 'index.php', 'w');
        fclose($index_file_handle);

        // Save files in array
        for ($i = 0; $i < $db_files_rel_count; $i++) {
            $file_data = $this->get_file_data($db_files_rel[$i]->id_file);
            $files[] = ZDM__DOWNLOADS_FILES_PATH . '/' . $file_data->folder_path . '/' . $file_data->file_name;
        }

        $zip = new ZipArchive;

        // Create zip archive
        if ($zip->open($file_path, ZipArchive::CREATE) === TRUE) {

            // Dateien ins Zip-Archiv einfügen
            for ($i = 0; $i < $db_files_rel_count; $i++) {
                $zip->addFile($files[$i], $this->get_file_data($db_files_rel[$i]->id_file)->file_name);
            }

            $zip->close();

            // Log
            $this->log('archive cache created', 'ID: ' . $archive_id . ', path: ' . $file_path);
        } else {
            // Log
            $this->log('error create archive cache', 'path: ' . $file_path);
        }

        // Determine the file size
        $file_size = $this->file_size_convert(filesize($file_path));

        // MD5 from file
        $archive_hash_md5 = md5_file($file_path);

        // SHA1 from file
        $archive_hash_sha1 = sha1_file($file_path);

        // Update data in archives
        $wpdb->update(
            $tablename_archives, 
            array(
                'archive_cache_path' => $archive_cache_path,
                'hash_md5'      => $archive_hash_md5,
                'hash_sha1'     => $archive_hash_sha1,
                'file_size'     => $file_size,
                'time_update'   => $time
            ), 
            array(
                'id' => $archive_id
            ));

        // update file_updated in files_rel
        $wpdb->update(
            $tablename_files_rel, 
            array(
                'file_updated'  => 0,
                'time_update'   => $time
            ), 
            array(
                'id_archive' => $archive_id
            ));

        // Get data from the database (files_rel)
        $db_files_rel_deleted = $wpdb->get_results(
            "
            SELECT id 
            FROM $tablename_files_rel 
            WHERE id_archive = '$archive_id' 
            AND file_deleted = '1'
            "
            );
        
        $db_files_rel_deleted_count = count($db_files_rel_deleted);

        // Deletes all entries from files_rel with file_deleted = '1' that point to the archive
        for ($i = 0; $i < $db_files_rel_deleted_count; $i++) { 
            $wpdb->delete(
                $tablename_files_rel, 
                array(
                    'id' => $db_files_rel_deleted[$i]->id
                ));
        }

        // Log
        $this->log('create archive cache' , 'ID: ' . $archive_id . ', path: ' . $file_path);
    }

    /**
     * Adds a dashboard widget
     *
     * @return void
     */
    public function dashboard_widget()
    {
        wp_add_dashboard_widget('zdm_dashboard_widget', __('Download statistics', 'zdm'), array($this, 'dashboard_widget_handler'));
    }

    /**
     * Dashboard widget content
     *
     * @return void
     */
    public function dashboard_widget_handler()
    {
        require_once (plugin_dir_path(__FILE__) . '../templates/admin_dashboard_widget.php');
    }

    /**
     * Deletes all data
     *
     * @return void
     */
    public function delete_all_data() {

        global $wpdb;

        // Database Table names
        $zdm_tablename_archives = $wpdb->prefix . "zdm_archives";
        $zdm_tablename_files = $wpdb->prefix . "zdm_files";
        $zdm_tablename_files_rel = $wpdb->prefix . "zdm_files_rel";

        ////////////////////
        // Delete archives
        ////////////////////
        
        $zdm_db_archives = $wpdb->get_results( 
            "
            SELECT * 
            FROM $zdm_tablename_archives
            "
        );

        $zdm_db_archives_count = count($zdm_db_archives);

        for ($i=0; $i < $zdm_db_archives_count; $i++) {

            if ($zdm_db_archives[$i]->archive_cache_path != '') {
            
                // Delete file and folder
                $zdm_cache_folder = ZDM__DOWNLOADS_CACHE_PATH . '/' . $zdm_db_archives[$i]->archive_cache_path;
                $zdm_cache_file = $zdm_cache_folder . '/' . $zdm_db_archives[$i]->zip_name . '.zip';
                $zdm_cache_index = $zdm_cache_folder . '/' . 'index.php';

                if (file_exists($zdm_cache_file)) {
                    unlink($zdm_cache_file);
                }
                if (file_exists($zdm_cache_index)) {
                    unlink($zdm_cache_index);
                }
                if (is_dir($zdm_cache_folder)) {
                    rmdir($zdm_cache_folder);
                }
            }

            // Delete database entries
            $wpdb->delete(
                $zdm_tablename_archives, 
                array(
                    'id' => $zdm_db_archives[$i]->id
                ));
        }

        ////////////////////
        // Delete files
        ////////////////////
        
        $zdm_db_file = $wpdb->get_results( 
            "
            SELECT * 
            FROM $zdm_tablename_files
            "
        );

        $zdm_db_file_count = count($zdm_db_file);

        for ($i=0; $i < $zdm_db_file_count; $i++) {
            
            // Delete file and folder
            $zdm_folder_path = ZDM__DOWNLOADS_FILES_PATH . '/' . $zdm_db_file[$i]->folder_path;
            $zdm_file_path = $zdm_folder_path . '/' . $zdm_db_file[$i]->file_name;
            $zdm_file_index = $zdm_folder_path . '/' . 'index.php';

            if (file_exists($zdm_file_path)) {
                unlink($zdm_file_path);
            }
            if (file_exists($zdm_file_index)) {
                unlink($zdm_file_index);
            }
            if (is_dir($zdm_folder_path)) {
                rmdir($zdm_folder_path);
            }

            // Delete database entries
            $wpdb->delete(
                $zdm_tablename_files, 
                array(
                    'id' => $zdm_db_file[$i]->id
                ));
        }

        ////////////////////
        // Delete files_rel in database
        ////////////////////
        
        $zdm_db_file_rel = $wpdb->get_results( 
            "
            SELECT id 
            FROM $zdm_tablename_files_rel
            "
        );

        $zdm_db_file_rel_count = count($zdm_db_file_rel);

        for ($i=0; $i < $zdm_db_file_rel_count; $i++) {

            // Delete database entries
            $wpdb->delete(
                $zdm_tablename_files_rel, 
                array(
                    'id' => $zdm_db_file_rel[$i]->id
                ));
        }

        ////////////////////
        // Delete main folder
        ////////////////////

        if (is_dir(ZDM__DOWNLOADS_CACHE_PATH)) {
            @rmdir(ZDM__DOWNLOADS_CACHE_PATH);
        }

        if (is_dir(ZDM__DOWNLOADS_FILES_PATH)) {
            @rmdir(ZDM__DOWNLOADS_FILES_PATH);
        }

        if (is_dir(ZDM__DOWNLOADS_PATH)) {
            @rmdir(ZDM__DOWNLOADS_PATH);
        }

        // Log
        $this->log('delete all data');
    }

    /**
     * Download control
     *
     * @return void
     */
    public function download() {

        // HTTP user agent
        $http_user_agent = @filter_input(INPUT_SERVER, 'HTTP_USER_AGENT');

        require_once(ZDM__PATH . '/lib/bot_user_agents.php');

        if (in_array($http_user_agent, ZDM__BOT_USER_AGENTS)) {
            // Access by bot
        } else {
            // Access by user

            ////////////////////
            // zip
            ////////////////////
            if (isset($_GET['zdownload'])) {

                $zdownload_url = base64_decode(filter_input(INPUT_GET, 'zdownload', FILTER_SANITIZE_URL));

                if ($zdownload_url != '' && is_numeric($zdownload_url)) {

                    if ($this->check_if_archive_exists($zdownload_url) === true) {

                        global $wpdb;
                        $tablename_archives = $wpdb->prefix . "zdm_archives";

                        // Get data from the database (archives)
                        $db_archive = $wpdb->get_results(
                            "
                            SELECT zip_name, count, archive_cache_path, status 
                            FROM $tablename_archives 
                            WHERE id = '$zdownload_url'
                            "
                            );
                        
                        if ($db_archive[0]->status != 'private') {
                            
                            // Update count
                            $count_new = $db_archive[0]->count + 1;
                            $wpdb->update(
                                $tablename_archives, 
                                array(
                                    'count'         => $count_new,
                                    'time_update'   => time()
                                ), 
                                array(
                                    'id' => $zdownload_url
                                ));
    
                            // Statistics
                            $this->log('download archive', $zdownload_url);
    
                            // Path for file
                            $zip_file = ZDM__DOWNLOADS_CACHE_PATH_URL . '/' . $db_archive[0]->archive_cache_path . '/' . $db_archive[0]->zip_name . '.zip';
    
                            // File size
                            $file_size = filesize($zip_file);
    
                            // Provide file
                            header('Content-Disposition: attachment; filename=' . $db_archive[0]->zip_name . '.zip');
                            header('Content-type: application/force-download');
                            header('Content-Length: ' . $file_size);
                            header('Content-type: ' . $db_archive[0]->file_type . '; charset=utf-8');

                            readfile($zip_file);
                            exit();
                        }
                    } // end if ($this->check_if_archive_exists($zdownload_url) === true)
                    else {
                        if ($this->repair_folder_token_name()) {
                            // TODO: Seite nochmal laden
                        }
                    }
                } // end if ($zdownload_url != '' && is_numeric($zdownload_url))
            } // end if (isset($_GET['zdownload']))

            ////////////////////
            // file
            ////////////////////
            if (isset($_GET['zdownload_f'])) {

                $zdownload_url = base64_decode(filter_input(INPUT_GET, 'zdownload_f', FILTER_SANITIZE_URL));

                if ($zdownload_url != '' && is_numeric($zdownload_url)) {

                    if ($this->check_if_file_exists($zdownload_url) === true) {

                        global $wpdb;
                        $tablename_files = $wpdb->prefix . "zdm_files";

                        // Get data from the database (files)
                        $db_files = $wpdb->get_results(
                            "
                            SELECT count, folder_path, file_name, file_type, status 
                            FROM $tablename_files 
                            WHERE id = '$zdownload_url'
                            "
                            );

                        if ($db_files[0]->status != 'private') {

                            // Update count
                            $count_new = $db_files[0]->count + 1;
                            $wpdb->update(
                                $tablename_files, 
                                array(
                                    'count'         => $count_new,
                                    'time_update'   => time()
                                ), 
                                array(
                                    'id' => $zdownload_url
                                ));

                            // Statistics
                            $this->log('download file', $zdownload_url);

                            if ($options['file-open-in-browser-pdf'] == 'on' && $db_files[0]->file_type == 'application/pdf') {
    
                                // External path for file
                                $file_path_url = ZDM__DOWNLOADS_FILES_PATH_URL . '/' . $db_files[0]->folder_path . '/' . $db_files[0]->file_name;
                                wp_redirect($file_path_url);
                                exit;
                            } else {

                                // Internal path for file
                                $file_path = ZDM__DOWNLOADS_FILES_PATH . '/' . $db_files[0]->folder_path . '/' . $db_files[0]->file_name;
    
                                // File size
                                $file_size = filesize($file_path);
    
                                // Provide file
                                header('Content-Disposition: attachment; filename=' . $db_files[0]->file_name);
                                header('Content-type: application/force-download');
                                header('Content-Length: ' . $file_size);
                                header('Content-type: ' . $db_files[0]->file_type . '; charset=utf-8');
                                readfile($file_path);
                            }
                        }
                    } // end if ($this->check_if_file_exists($zdownload_url) === true)
                    else {
                        if ($this->repair_folder_token_name()) {
                            // TODO: Seite nochmal laden
                        }
                    }
                } // end if ($zdownload_url != '' && is_numeric($zdownload_url))
            } // end if (isset($_GET['zdownload_f']))
        } // end else (in_array($http_user_agent, ZDM__BOT_USER_AGENTS))
    }

    /**
     * Returns the respective CSS classes for the download button
     *
     * @return CSS class
     */
    public function download_button_class() {

        $options = get_option('zdm_options');

        // Standard CSS class
        $class = 'button zdm-btn';

        if ($options['download-btn-outline'] == 'on') {
            $outline = '-outline';
        } else {
            $outline = '';
        }

        $class .= ' zdm-btn-style-' . $options['download-btn-style'] . $outline;

        if ($options['download-btn-border-radius'] != 'none') {
            $class .= ' zdm-btn-radius' . $options['download-btn-border-radius'];
        }

        return $class;
    }

    /**
     * Integrates admin scripts
     *
     * @return void
     */
    public function enqueue_admin_scripts() {
        // Admin CSS
        wp_register_style('zdm_admin_styles', plugins_url('../admin/css/zdm_admin_style.min.css?ver=' . ZDM__VERSION, __FILE__));
        wp_enqueue_style('zdm_admin_styles');

        // Ionicons CSS
        wp_register_style('zdm_admin_styles_ionic', 'https://cdnjs.cloudflare.com/ajax/libs/ionicons/4.5.6/css/ionicons.min.css');
        wp_enqueue_style('zdm_admin_styles_ionic');

        // Ionicons JS
        wp_register_script('zdm_admin_ionic_js', 'https://unpkg.com/ionicons@4.5.10-0/dist/ionicons.js');
        wp_enqueue_script('zdm_admin_ionic_js');
    }

    /**
     * Integrates frontend scripts
     *
     * @return void
     */
    public function enqueue_frontend_scripts() {
        // Frontend CSS
        wp_register_style('zdm_styles', plugins_url('../public/css/zdm_style.min.css?ver=' . ZDM__VERSION, __FILE__));
        wp_enqueue_style('zdm_styles');

        // Ionicons CSS
        wp_register_style('zdm_styles_ionic', 'https://cdnjs.cloudflare.com/ajax/libs/ionicons/4.5.6/css/ionicons.min.css');
        wp_enqueue_style('zdm_styles_ionic');

        // Ionicons JS
        wp_register_script('zdm_ionic_js', 'https://unpkg.com/ionicons@4.5.10-0/dist/ionicons.js');
        wp_enqueue_script('zdm_ionic_js');
    }

    /**
     * Converts Bytes to B, KB, MB, GB, TB
     * 
     * @param int $bytes Bytes as input
     * @return string
     */
    public function file_size_convert($bytes) {
        $bytes = floatval($bytes);
        $arBytes = array(
            0 => array(
                "UNIT" => "TB",
                "VALUE" => pow(1024, 4)
            ),
            1 => array(
                "UNIT" => "GB",
                "VALUE" => pow(1024, 3)
            ),
            2 => array(
                "UNIT" => "MB",
                "VALUE" => pow(1024, 2)
            ),
            3 => array(
                "UNIT" => "KB",
                "VALUE" => 1024
            ),
            4 => array(
                "UNIT" => "B",
                "VALUE" => 1
            ),
        );

        foreach($arBytes as $arItem) {
            if ($bytes >= $arItem["VALUE"]) {
                $result = $bytes / $arItem["VALUE"];
                $result = str_replace(".", "," , strval(round($result, 2)))." ".$arItem["UNIT"];
                break;
            }
        }
        return $result;
    }

    /**
     * Converts strings to bytes
     * 
     * @param string $str String as from ini_get ('upload_max_filesize')
     * @return mixed
     */
    public function file_size_convert_str2bytes($str) {
        // Strings only
        $unit_byte = preg_replace('/[^a-zA-Z]/', '', $str);
        $unit_byte = strtolower($unit_byte);
        // Numbers only (allow decimal point)
        $num_val = preg_replace('/\D\.\D/', '', $str);
        switch ($unit_byte) {
            case 'p':	// petabyte
            case 'pb':
                $num_val *= 1024;
            case 't':	// terabyte
            case 'tb':
                $num_val *= 1024;
            case 'g':	// gigabyte
            case 'gb':
                $num_val *= 1024;
            case 'm':	// megabyte
            case 'mb':
                $num_val *= 1024;
            case 'k':	// kilobyte
            case 'kb':
                $num_val *= 1024;
            case 'b':	// byte
                return $num_val *= 1;
                break;
            default:
                return FALSE;
        }
        return FALSE;
    }

    /**
     * Fetches all data from the database of an archive
     *
     * @param int $archive_id
     * @return void
     */
    public function get_archive_data($archive_id) {
        global $wpdb;

        $tablename_archives = $wpdb->prefix . "zdm_archives";

        // Get data from the database (archives)
        $db_archive = $wpdb->get_results(
            "
            SELECT * 
            FROM $tablename_archives 
            WHERE id = '$archive_id'
            "
            );

        return $db_archive[0];
    }

    /**
     * Retrieves all archive IDs in which the file is linked
     *
     * @param int $file_id
     * @return array
     */
    public function get_linked_archives($file_id) {
        global $wpdb;

        $tablename_files_rel = $wpdb->prefix . "zdm_files_rel";

        // Get data from the database (files_rel)
        $db_archive = $wpdb->get_results(
            "
            SELECT id_archive 
            FROM $tablename_files_rel 
            WHERE id_file = '$file_id'
            "
            );

        return $db_archive;
    }

    /**
     * Returns archive name
     *
     * @param int $archive_id
     * @return string
     */
    public function get_archive_name($archive_id) {
        global $wpdb;

        $tablename_archives = $wpdb->prefix . "zdm_archives";

        // Get data from the database (archives)
        $db_archive = $wpdb->get_results(
            "
            SELECT name 
            FROM $tablename_archives 
            WHERE id = '$archive_id'
            "
            );

        return $db_archive[0]->name;
    }

    /**
     * Checks the hash value of a file
     *
     * @param string $type
     * @param string $hash
     * @return int Number of hashes found
     */
    public function get_count_of_files_by_hash($type, $hash) {
        global $wpdb;

        $tablename_files = $wpdb->prefix . "zdm_files";

        if ($type == 'md5') {

            // Get data from the database (files)
            $db_file = $wpdb->get_results(
                "
                SELECT id 
                FROM $tablename_files 
                WHERE hash_md5 = '$hash'
                "
                );
        }

        if ($type == 'sha1') {

            // Get data from the database (files)
            $db_file = $wpdb->get_results(
                "
                SELECT id 
                FROM $tablename_files 
                WHERE hash_sha1 = '$hash'
                "
                );
        }

        if ($db_file[0] === NULL) {
            return count($db_file);
        } else {
            return count($db_file);
        }
    }

    /**
     * Returns the ID of the currently logged in user
     * 
     * @return int WordPress user ID
     */
    public function get_current_user_id() {
        if (!function_exists('wp_get_current_user'))
            return 0;
        $user = wp_get_current_user();
        return (isset($user->ID) ? (int) $user->ID : 0);
    }

    /**
     * Returns object with all data from database (files)
     * 
     * @param int $file_id
     * @return object
     */
    public function get_file_data($file_id) {
        global $wpdb;

        $tablename_files = $wpdb->prefix . "zdm_files";

        // Get data from the database (files)
        $db_file = $wpdb->get_results(
            "
            SELECT * 
            FROM $tablename_files 
            WHERE id = '$file_id'
            "
            );

        return $db_file[0];
    }

    /**
     * Returns array with MD5 hashes of all files
     *
     * @return array
     */
    public function get_files_md5() {
        global $wpdb;

        $tablename_files = $wpdb->prefix . "zdm_files";

        // Get data from the database (files)
        $db_files_md5 = $wpdb->get_results(
            "
            SELECT hash_md5 
            FROM $tablename_files
            "
            );
        
        $db_files_md5_count = count($db_files_md5);
        
        for ($i=0; $i < $db_files_md5_count; $i++) { 
            $files_md5[] = $db_files_md5[$i]->hash_md5;
        }

        return $files_md5;
    }

    /**
     * Returns name of file
     * 
     * @param int $file_id
     * @return object
     */
    public function get_file_name($file_id) {
        global $wpdb;

        $tablename_files = $wpdb->prefix . "zdm_files";

        // Get data from the database (files)
        $db_file = $wpdb->get_results(
            "
            SELECT name 
            FROM $tablename_files 
            WHERE id = '$file_id'
            "
            );

        return $db_file[0]->name;
    }

    /**
     * Checks the license key
     * 
     * @return bool Returns true if valid and false if not
     */
    public function licence() {
        $options = get_option('zdm_options');

        if ($options['licence-key'] != '') {

            $timeDiff = time() - $options['licence-time'];

            if ($timeDiff > 2592000) { // 2592000 = 30 days
                
                $licence_array = $this->licence_array();

                if ($licence_array['success'] === true) {

                    $options['licence-email'] = $licence_array['purchase']['email'];
                    $options['licence-purchase'] = $licence_array['purchase']['created_at'];
                    $options['licence-product-name'] = $licence_array['purchase']['product_name'];
                    $options['licence-time'] = time();

                    if (add_option('zdm_options', $options) === FALSE) {
                        update_option('zdm_options', $options);
                    }

                    $options = get_option('zdm_options');

                    return true;
                } else {

                    $options['licence-key'] = '';
                    $options['licence-email'] = '';
                    $options['licence-purchase'] = '';
                    $options['licence-product-name'] = '';
                    $options['licence-time'] = 0;

                    if (add_option('zdm_options', $options) === FALSE) {
                        update_option('zdm_options', $options);
                    }

                    $options = get_option('zdm_options');

                    return false;
                }
            } else {
                return true;
            }
        } else {

            $options['licence-email'] = '';
            $options['licence-purchase'] = '';
            $options['licence-product-name'] = '';
            $options['licence-time'] = 0;

            if (add_option('zdm_options', $options) === FALSE) {
                update_option('zdm_options', $options);
            }

            $options = get_option('zdm_options');

            return false;
        }
    }

    /**
     * Returns data from Gumroad in array
     * 
     * @param string $licence_key
     * @return mixed Array if valid, false if not
     */
    public static function licence_array($licence_key = '') {
        if ($licence_key == '') {
            $options = get_option('zdm_options');
            $licence_key = $options['licence-key'];
        }

        $post_data = array(
            'product_permalink' => 'zdPRE',
            'license_key' => $licence_key,
            'increment_uses_count' => 'false'
        );

        $args = array(
            'body' => $post_data,
            'timeout' => '5',
            'redirection' => '5',
            'httpversion' => '1.0',
            'blocking' => true,
            'headers' => array(),
            'cookies' => array()
        );

        $url = wp_remote_post('https://api.gumroad.com/v2/licenses/verify', $args);

        $array = json_decode($url['body'], true);

        if ($array['success'] === true) {
            return $array;
        } else {
            return false;
        }
    }

    /**
     * Log
     * 
     * @param string $type Type of log
     * @param string $message Other Information
     * @return void
     */
    public function log($type, $message = '---') {
        // user IP address
        if (filter_input(INPUT_SERVER, 'REMOTE_ADDR')) {

            $options = get_option('zdm_options');

            $user_ip = filter_input(INPUT_SERVER, 'REMOTE_ADDR');

            // Anonymize the IP address
            if ($options['secure-ip'] === 'on') {
                require_once(ZDM__PATH . '/lib/ZDMIPAnonymizer.php');
                $ip_anonymizer = new ZDMIPAnonymizer();
                $user_ip = $ip_anonymizer->anonymize($user_ip);
            }
        } else {
            $user_ip = "---";
        }

        // HTTP user agent
        if (filter_input(INPUT_SERVER, 'HTTP_USER_AGENT')) {
            $http_user_agent = filter_input(INPUT_SERVER, 'HTTP_USER_AGENT');
        } else {
            $http_user_agent = "---";
        }

        global $wpdb;
        
        $tablename_log = $wpdb->prefix . "zdm_log";

        // Save log in database
        $wpdb->insert(
            $tablename_log, 
            array(
                'type'          => htmlspecialchars($type),
                'message'       => htmlspecialchars($message),
                'user_agent'    => $http_user_agent,
                'user_ip'       => $user_ip,
                'user_id'       => ZDMCore::get_current_user_id(),
                'time_create'   => time()
            )
        );
    }

    /**
     * Formats numbers and scores a point for every thousand steps
     * 
     * @param int $number
     * @return string Formatted number
     */
    public function number_format($number) {

        if (in_array(get_locale(), ZDM__COUNTRIES_USING_DECIMAL_POINT)) {
            return number_format($number, 0, '.', ',');
        } else {
            return number_format($number, 0, ',', '.');
        }
    }

    /**
     * Registers basic components in WP
     *
     * @return void
     */
    public function register() {

        // Include admin scripts
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_scripts'));

        // Include frontend scripts
        add_action('wp_enqueue_scripts', array($this, 'enqueue_frontend_scripts'));

        // Admin menu
        add_action('admin_menu', array($this, 'admin_menu'));

        // Dashboard widget
        add_action('wp_dashboard_setup', array($this, 'dashboard_widget'));

        // Inserts links in the plugin overview
        add_filter('plugin_action_links_' . $this->plugin_basename, array($this, 'settings_link'));

        // Shortcode download archive and file
        add_shortcode('zdownload', array($this, 'shortcode_download'));

        // Shortcode audio output
        add_shortcode('zdownload_audio', array($this, 'shortcode_audio'));

        // Shortcode metadata output
        add_shortcode('zdownload_meta', array($this, 'shortcode_meta'));

        // Shortcode video output
        add_shortcode('zdownload_video', array($this, 'shortcode_video'));
    }

    /**
     * Checks if folder token name is equal, otherwise it will be repaired
     *
     * @return bool true: if repair was successful, otherwise: false
     */
    public function repair_folder_token_name() {

        $options = get_option('zdm_options');
        
        $dir =  wp_upload_dir()['basedir'];
        $dir_array = scandir($dir);
        $regex_search = '/z-downloads-.{32}/';
        $dir_count = count($dir_array);
        for ($i=0; $i < $dir_count; $i++) { 
            
            if (preg_match($regex_search, $dir_array[$i])) {

                if ($dir_array[$i] != 'z-downloads-' . $options['download-folder-token']) {
                    rename(wp_upload_dir()['basedir'] . '/' . $dir_array[$i], wp_upload_dir()['basedir'] . '/z-downloads-' . $options['download-folder-token']);
                    ZDMCore::log('folder token repaired');
                    return true;
                } else {
                    return false;
                }
            }
        }
    }

    /**
     * Inserts links in the plugin overview
     *
     * @param string $links
     * @return string
     */
    public function settings_link($links) {
        $settings_link = '<a href="admin.php?page=z-downloads-settings">Einstellungen</a>';
        array_push($links, $settings_link);
        return $links;
    }

    /**
     * Shortcode for HTML5 audio player: [zdownload_audio file="123"]
     *
     * @param string $atts
     * @param string $content
     * @return void HTML5 Audioplayer
     */
    public function shortcode_audio($atts, $content = null) {

        $atts = shortcode_atts(
            array(
                'file'      => '',
                'autoplay'  => '',
                'loop'      => '',
                'controls'  => ''
                ), $atts
        );
        
        $file = htmlspecialchars($atts['file']);
        if (htmlspecialchars($atts['autoplay']) == 'on') {
            $autoplay = ' autoplay';
        } else {
            $autoplay = '';
        }
        if (htmlspecialchars($atts['loop']) == 'on') {
            $loop = ' loop';
        } else {
            $loop = '';
        }
        if (htmlspecialchars($atts['controls']) == 'on') {
            $controls = '';
        } else {
            $controls = ' controls';
        }

        if ($file != '') {

            global $wpdb;
            $tablename_files = $wpdb->prefix . "zdm_files";

            // Get data from the database (files)
            $db_file = $wpdb->get_results(
                "
                SELECT id, folder_path, file_name, file_type, status 
                FROM $tablename_files 
                WHERE id = '$file'
                "
                );

            if ($db_file[0]->status != 'private') {

                // Output
                $audio = '<audio preload="none" id="zdmAudio' . $db_file[0]->id . '" class="zdm-audio"' . $autoplay . $loop . $controls . '>';
                $audio .= esc_html__('Your browser does not support HTML audio elements.', 'zdm');
                $audio .= '<source src="' . ZDM__DOWNLOADS_FILES_PATH_URL . '/' . $db_file[0]->folder_path . '/' . $db_file[0]->file_name . '" type="' . $db_file[0]->file_type . '">';
                $audio .= '</audio>';
    
                if (in_array($db_file[0]->file_type, ZDM__MIME_TYPES_AUDIO)) {
                    return $audio;
                }
            }
        }
    }

    /**
     * Shortcode for downloads: [zdownload zip="123"] or [zdownload file="123"]
     * 
     * @return string
     */
    public function shortcode_download($atts, $content = null) {

        $atts = shortcode_atts(
            array(
                'zip'   => '',
                'file'  => ''
                ), $atts
        );
        
        $zip = htmlspecialchars($atts['zip']);
        $file = htmlspecialchars($atts['file']);

        ////////////////////
        // zip
        ////////////////////
        if ($zip != '') {
            // Check whether a file is assigned at all
            if ($this->check_if_any_file_rel_to_archive($zip)) {

                $options = get_option('zdm_options');

                // Check files are up-to-date
                $this->check_files_from_archive($zip);

                global $wpdb;
                $tablename_archives = $wpdb->prefix . "zdm_archives";

                // Get data from the database (archives)
                $db_archive = $wpdb->get_results(
                    "
                    SELECT id, button_text, status 
                    FROM $tablename_archives 
                    WHERE id = '$zip'
                    "
                    );
                
                if ($db_archive[0]->status != 'private') {

                    // Determine text button
                    if ($options['download-btn-icon-only'] != '') {
                        $download_text = '';
                        $icon_class = '  zdm-btn-icon-only';
                    } else {
    
                        if ($db_archive[0]->button_text != '') {
                            $download_text = $db_archive[0]->button_text;
                        } else {
                            $download_text = $options['download-btn-text'];
                        }
    
                        $icon_class = ' zdm-btn-icon';
                    }
    
                    $type = 'zdownload';
                    $id = base64_encode($db_archive[0]->id);
    
                    // Output
                    if ($options['download-btn-icon'] != 'none') {
                        $icon = '<ion-icon name="' . $options['download-btn-icon'] . '" class="' . $icon_class . '"></ion-icon>';
                    } else {
                        $icon = '';
                    }
    
                    return '<a href="?' . $type . '=' . $id . '" id="zdmBtn' . htmlspecialchars($db_archive[0]->id) . '" class="' . $this->download_button_class() . '" target="_blank" rel="nofollow">' . $icon . $download_text . '</a>';
                }
            } else {
                // Empty return value if no file is linked
                return '';
            }
        } // end if ($zip != '')

        ////////////////////
        // file
        ////////////////////
        if ($file != '') {

            if ($this->check_if_file_exists($file) === true) {

                $options = get_option('zdm_options');

                global $wpdb;
                $tablename_files = $wpdb->prefix . "zdm_files";

                // Get data from the database (files)
                $db_files = $wpdb->get_results(
                    "
                    SELECT id, button_text, folder_path, file_name, file_type, status 
                    FROM $tablename_files 
                    WHERE id = '$file'
                    "
                    );

                if ($db_files[0]->status != 'private') {

                    // Determine text button
                    if ($options['download-btn-icon-only'] != '') {
                        $download_text = '';
                        $icon_class = '  zdm-btn-icon-only';
                    } else {
    
                        if ($db_files[0]->button_text != '') {
                            $download_text = $db_files[0]->button_text;
                        } else {
                            $download_text = $options['download-btn-text'];
                        }
    
                        $icon_class = ' zdm-btn-icon';
                    }
    
                    $type = 'zdownload_f';
                    $id = base64_encode($db_files[0]->id);
    
                    // Output
                    if ($options['download-btn-icon'] != 'none') {
                        $icon = '<ion-icon name="' . $options['download-btn-icon'] . '" class="' . $icon_class . '"></ion-icon>';
                    } else {
                        $icon = '';
                    }
    
                    // HTTP user agent
                    $http_user_agent = @filter_input(INPUT_SERVER, 'HTTP_USER_AGENT');
    
                    require_once(ZDM__PATH . '/lib/bot_user_agents.php');
    
                    if (in_array($http_user_agent, ZDM__BOT_USER_AGENTS)) {
                        // Access by bot
                    } else {
                        // Access by user
    
                        return '<a href="?' . $type . '=' . $id . '" id="zdmBtn' . htmlspecialchars($db_files[0]->id) . '" class="' . $this->download_button_class() . '" target="_blank" rel="nofollow">' . $icon . $download_text . '</a>';
                    }
                }
            }
        } // end if ($file != '')
    }

    /**
     * Shortcode for metadata output: [zdownload_meta zip="123" type="count"]
     * 
     * @return string Metadaten Ausgabe
     */
    public function shortcode_meta($atts, $content = null) {

        $atts = shortcode_atts(
            array(
                'zip'   => '',
                'file'  => '',
                'type'  => ''
                ), $atts
        );
        
        $zip = htmlspecialchars($atts['zip']);
        $file = htmlspecialchars($atts['file']);
        $type = htmlspecialchars($atts['type']);

        if ($type != '') {

            ////////////////////////////////////////////////////////////
            ////////////////////////////////////////////////////////////
            // zip
            ////////////////////////////////////////////////////////////
            ////////////////////////////////////////////////////////////
            if ($zip != '') {

                global $wpdb;
                $tablename_archives = $wpdb->prefix . "zdm_archives";

                ////////////////////
                // Count: Number of downloads
                ////////////////////
                if ($type === 'count') {

                    // Get data from the database (archives)
                    $db_archive = $wpdb->get_results(
                        "
                        SELECT count, status 
                        FROM $tablename_archives 
                        WHERE id = '$zip'
                        "
                        );

                    if ($db_archive[0]->status != 'private') {
                        return htmlspecialchars($this->number_format($db_archive[0]->count));
                    }
                }

                ////////////////////
                // File size
                ////////////////////
                if ($type === 'size') {
                    
                    // Check ob überhaupt eine Datei zugewiesen ist
                    if ($this->check_if_any_file_rel_to_archive($zip)) {

                        // Dateien auf Aktualität prüfen
                        $this->check_files_from_archive($zip);

                        global $wpdb;
                        $tablename_archives = $wpdb->prefix . "zdm_archives";

                        // Get data from the database (archives)
                        $db_archive = $wpdb->get_results(
                            "
                            SELECT file_size, status 
                            FROM $tablename_archives 
                            WHERE id = '$zip'
                            "
                            );

                        if ($db_archive[0]->status != 'private') {
                            return htmlspecialchars($db_archive[0]->file_size);
                        }
                    }
                }

                ////////////////////
                // Name
                ////////////////////
                if ($type === 'name') {

                    // Get data from the database (archives)
                    $db_archive = $wpdb->get_results(
                        "
                        SELECT name, status 
                        FROM $tablename_archives 
                        WHERE id = '$zip'
                        "
                        );

                    if ($db_archive[0]->status != 'private') {
                        return htmlspecialchars($db_archive[0]->name);
                    }
                }

                ////////////////////
                // Filename
                ////////////////////
                if ($type === 'filename') {

                    // Get data from the database (archives)
                    $db_archive = $wpdb->get_results(
                        "
                        SELECT zip_name, status 
                        FROM $tablename_archives 
                        WHERE id = '$zip'
                        "
                        );

                    if ($db_archive[0]->status != 'private') {
                        return htmlspecialchars($db_archive[0]->zip_name . '.zip');
                    }
                }

                ////////////////////
                // Hash MD5, Sha1
                ////////////////////
                if ($type === 'hash-md5' OR $type === 'hash-sha1') {
                    
                    // Check whether a file is assigned at all
                    if ($this->check_if_any_file_rel_to_archive($zip)) {

                        // Check files are up-to-date
                        $this->check_files_from_archive($zip);

                        global $wpdb;
                        $tablename_archives = $wpdb->prefix . "zdm_archives";

                        // Get data from the database (archives)
                        $db_archive = $wpdb->get_results(
                            "
                            SELECT hash_md5, hash_sha1, status 
                            FROM $tablename_archives 
                            WHERE id = '$zip'
                            "
                            );

                        if ($db_archive[0]->status != 'private') {

                            // File size output
                            if ($this->licence() != true) {
                                
                            } else {
                                if ($type === 'hash-md5') {
                                    return htmlspecialchars($db_archive[0]->hash_md5);
                                } elseif ($type === 'hash-sha1') {
                                    return htmlspecialchars($db_archive[0]->hash_sha1);
                                }
                            }
                        }
                    }
                }
            } // end $zip != ''

            ////////////////////////////////////////////////////////////
            ////////////////////////////////////////////////////////////
            // file
            ////////////////////////////////////////////////////////////
            ////////////////////////////////////////////////////////////
            if ($file != '') {
                    
                global $wpdb;
                $tablename_files = $wpdb->prefix . "zdm_files";

                ////////////////////
                // Count: Number of downloads
                ////////////////////
                if ($type === 'count') {
        
                    // Get data from the database (files)
                    $db_files = $wpdb->get_results(
                        "
                        SELECT count, status 
                        FROM $tablename_files 
                        WHERE id = '$file'
                        "
                        );

                    if ($db_files[0]->status != 'private') {
                        return htmlspecialchars($this->number_format($db_files[0]->count));
                    }
                }

                ////////////////////
                // File size
                ////////////////////
                if ($type === 'size') {
                    
                    // Get data from the database (files)
                    $db_files = $wpdb->get_results(
                        "
                        SELECT file_size, status 
                        FROM $tablename_files 
                        WHERE id = '$file'
                        "
                        );

                    if ($db_files[0]->status != 'private') {
                        return htmlspecialchars($db_files[0]->file_size);
                    }
                }

                ////////////////////
                // Name
                ////////////////////
                if ($type === 'name') {

                    // Get data from the database (files)
                    $db_files = $wpdb->get_results(
                        "
                        SELECT name, status 
                        FROM $tablename_files 
                        WHERE id = '$file'
                        "
                        );

                    if ($db_files[0]->status != 'private') {
                        return htmlspecialchars($db_files[0]->name);
                    }
                }

                ////////////////////
                // Filename
                ////////////////////
                if ($type === 'filename') {

                    // Get data from the database (files)
                    $db_files = $wpdb->get_results(
                        "
                        SELECT file_name, status 
                        FROM $tablename_files 
                        WHERE id = '$file'
                        "
                        );

                    if ($db_files[0]->status != 'private') {
                        return htmlspecialchars($db_files[0]->file_name);
                    }
                }

                ////////////////////
                // Hash MD5, Sha1
                ////////////////////
                if ($type === 'hash-md5' OR $type === 'hash-sha1') {

                    // Get data from the database (files)
                    $db_files = $wpdb->get_results(
                        "
                        SELECT hash_md5, hash_sha1, status 
                        FROM $tablename_files 
                        WHERE id = '$file'
                        "
                        );

                    if ($db_files[0]->status != 'private') {

                        // File size output
                        if ($this->licence() != true) {
                            
                        } else {
                            if ($type === 'hash-md5') {
                                return htmlspecialchars($db_files[0]->hash_md5);
                            } elseif ($type === 'hash-sha1') {
                                return htmlspecialchars($db_files[0]->hash_sha1);
                            }
                        }
                    }
                }
            } // end if ($file != '')
            
        } // end if ($type != '')
    }

    /**
     * Shortcode for HTML5 video player: [zdownload_video file="123"]
     * 
     * @return string HTML5 video player
     */
    public function shortcode_video($atts, $content = null) {

        $atts = shortcode_atts(
            array(
                'file'      => '',
                'w'         => '100%',
                'autoplay'  => '',
                'loop'      => '',
                'controls'  => ''
                ), $atts
        );
        
        $file = htmlspecialchars($atts['file']);
        $width = htmlspecialchars($atts['w']);
        if (htmlspecialchars($atts['autoplay']) == 'on') {
            $autoplay = ' autoplay';
        } else {
            $autoplay = '';
        }
        if (htmlspecialchars($atts['loop']) == 'on') {
            $loop = ' loop';
        } else {
            $loop = '';
        }
        if (htmlspecialchars($atts['controls']) == 'on') {
            $controls = '';
        } else {
            $controls = ' controls';
        }

        if ($file != '') {

            global $wpdb;
            $tablename_files = $wpdb->prefix . "zdm_files";

            // Get data from the database (files)
            $db_file = $wpdb->get_results(
                "
                SELECT id, folder_path, file_name, file_type, status 
                FROM $tablename_files 
                WHERE id = '$file'
                "
                );

            if ($db_file[0]->status != 'private') {

                // Output
                $video = '<video id="zdmVideo' . $db_file[0]->id . '" width="' . $width . '" class="zdm-video"' . $autoplay . $loop . $controls . '>';
                $video .= esc_html__('Your browser does not support HTML video elements.', 'zdm');
                $video .= '<source src="' . ZDM__DOWNLOADS_FILES_PATH_URL . '/' . $db_file[0]->folder_path . '/' . $db_file[0]->file_name . '" type="' . $db_file[0]->file_type . '">';
                $video .= '</video>';

                if (in_array($db_file[0]->file_type, ZDM__MIME_TYPES_VIDEO)) {
                    return $video;
                }
            }
        }
    }
}
